import { ReactElement } from "react";
import { useTheme } from "@mui/material";
import { LabeledIcon } from "@ess-ics/ce-ui-common";
import {
  Brightness1,
  RadioButtonUnchecked,
  HelpOutline
} from "@mui/icons-material";
import { Record as ApiRecord } from "../../store/deployApi";

export function RecordStatusIcon({ record }: { record: ApiRecord }) {
  const theme = useTheme();

  const { pvStatus } = record;

  const iconConfig: Record<string, { title: string; icon: ReactElement }> = {
    active: {
      title: "Active",
      icon: <Brightness1 />
    },
    inactive: {
      title: "Inactive",
      icon: <RadioButtonUnchecked />
    },
    null: {
      title: "Unknown",
      icon: <HelpOutline />
    }
  };

  const state = pvStatus ? pvStatus.toLowerCase() : "null";
  const iconStyle = { fill: theme.palette.status.icons };
  const iconTitle = iconConfig[state].title;
  const statusIcon = iconConfig[state].icon;

  return (
    <LabeledIcon
      label={iconTitle}
      labelPosition="tooltip"
      Icon={statusIcon}
      IconProps={{ style: iconStyle }}
    />
  );
}
